Apollo

Struct Apollo 

pub struct Apollo {
    pub logging_level: Levels,
}

Fields

logging_level: Levels

Implementations

Source

impl Apollo

pub fn new() -> Apollo

Creates a new Apollo instance

Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new(); // The default logging level is Debug

l.debug("This message will be printed");
l.warn("This message will also be printed");

If you require a different logging level, please use the following code instead

use crate::apollo_logger::Apollo;
use crate::apollo_logger::levels::Levels;

let l = Apollo { logging_level: Levels::INFO };

l.debug("This message will NOT printed");
l.warn("This message will be printed");
pub fn debug(&self, s: &str) -> Option<String>

Prints a message to the console with the DEBUG label_format

Arguments
  • s: String to print to the console
Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new();

l.warn("This is an debug message");
pub fn info(&self, s: &str) -> Option<String>

Prints a message to the console with the INFO label_format

Arguments
  • s: String to print to the console
Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new();

l.info("This is an info message");
pub fn warn(&self, s: &str) -> Option<String>

Prints a message to the console with the WARN label_format

Arguments
  • s: String to print to the console
Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new();

l.warn("This is an warning message");
pub fn error(&self, s: &str) -> Option<String>

Prints a message to the console with the ERROR label_format

Arguments
  • s: String to print to the console
Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new();

l.error("This is an error message");
pub fn critical(&self, s: &str) -> Option<String>

Prints a message to the console with the CRITICAL label_format

Arguments
  • s: String to print to the console
Examples
use crate::apollo_logger::Apollo;

let l = Apollo::new();

l.critical("This is an critical message");